@@ -9,12 +9,15 @@ sub replace {
     my ($self, $table_name, $args) = @_;
 
     my $table = $self->schema->get_table($table_name);
+    if (! $table) {
+        Carp::croak( "Table definition for $table_name does not exist (Did you declare it in our schema?)" );
+    }
 
     for my $col (keys %{$args}) {
         $args->{$col} = $table->call_deflate($col, $args->{$col});
     }
 
-    my ($sql, @binds) = $self->sql_builder->insert( $table_name, $args, { prefix => 'REPLACE' } );
+    my ($sql, @binds) = $self->sql_builder->insert( $table_name, $args, { prefix => 'REPLACE INTO' } );
     $self->_execute($sql, \@binds, $table_name);
 
     my $pk = $table->primary_keys();
